@@ -185,6 +185,13 @@ class Seeker:
         matched = re.search(extract_method_pattern, key)
         return matched.group(1)
 
+    @staticmethod
+    def match_import(key):
+        # "some literal string";
+        literal_string = '^\s*[\w\.]+$'
+        literal_matcher = re.compile(literal_string)
+        return literal_matcher.match(key)
+
     def process_key(self, key_and_location, white_list, search_pattern):
         """
         Input: a tuple of  (key, file location), and white_list of keys, and a search pattern
@@ -208,6 +215,8 @@ class Seeker:
             key = self.find_variable_value(key, location, white_list)
             if key is not None:
                 return key, location
+        elif self.match_import(key):
+            return key, location
         else:
             return None
 
@@ -313,6 +322,26 @@ class Seeker:
                     values.add(atty)
         return values
 
+    def is_messages_object(self, key):
+        # ie. Messages message = blah
+        messages_pattern = '^Messages \w+'
+        messages_matcher = re.compile(messages_pattern)
+        return  messages_matcher.match(key)
+
+    def messages_search_patterns(self, key, full_search_pattern):
+
+        specific_string_search = re.search('(".+?")', full_search_pattern)
+        if not specific_string_search is None:
+            lookfor = specific_string_search.group(0)
+        else:
+            lookfor = '.*?'
+        messages_pattern = '^Messages (\w+)'
+        messages_matcher = re.compile(messages_pattern)
+        obj = messages_matcher.match(key).group(1)
+        search_pattern = obj + '.get\('+lookfor
+        extract_pattern = obj + '.get\(({0})\)'.format(lookfor)
+        return search_pattern, extract_pattern
+
     def search_source_for_pattern(self, path, search_pattern, extract_pattern, white_list):
         """
         Searches all files recursively from given path for the search_pattern.
@@ -331,6 +360,16 @@ class Seeker:
                     key_and_location = self.extract_pattern_and_location_from_grep(line, extract_pattern)
                 if key_and_location is None:
                     continue
+
+                if self.is_messages_object(key_and_location[0]):
+                    messages_search_pattern, messages_extract_pattern = self.messages_search_patterns(key_and_location[0], search_pattern)
+                    hits = self.search_source_for_pattern(key_and_location[1], messages_search_pattern, messages_extract_pattern, white_list)
+                    hits_with_location = set()
+                    for hit in hits:
+                        hits_with_location.add((hit[0], key_and_location[1]))
+                    keys = keys|hits_with_location
+                    continue
+
                 stripped_key_and_location = self.process_key(key_and_location, white_list, search_pattern)
                 if stripped_key_and_location is not None:
                     keys.add(stripped_key_and_location)
@@ -339,6 +378,11 @@ class Seeker:
             pass
         return keys
 
+    def replace_location(self, key_and_location):
+
+        key_and_location[1] = '/home'
+        return (key_and_location[0], key_and_location[1])
+
     def in_grep_whitelist(self, line, white_list_patterns):
         """
         Tests whether an output line from grep matches whitelist patterns,
