@@ -7,11 +7,10 @@ from IzVerifier.izverifier import IzVerifier
 
 path1 = 'data/sample_installer_iz5/izpack/'
 path2 = 'data/sample_installer_iz5/resources/'
-source_path2 = 'data/sample_code_base'
+source_path2 = 'data/sample_code_base/src/'
 pom = 'data/sample_installer_iz5/pom.xml'
 
 
-
 class TestDependencies(unittest.TestCase):
     """
     Basic testing of verifier class.
@@ -34,9 +33,10 @@ class TestDependencies(unittest.TestCase):
                           'or.cycle.1', 'or.cycle.2', 'or.cycle.3',
                           'some.condition.1', 'some.condition.2',
                           'variable1',
-                          'myinstallerclass.condition', 'short.1'}
+                          'myinstallerclass.condition', 'short.1',
+                          'static.field.condition1', 'static.field.condition2'}
 
-        results = self.izv.dependency_verification(verbosity=2, fail_on_undefined_vars=True)
+        results = self.izv.dependency_verification(verbosity=2, fail_on_undefined_vars=True, filter_classes=True)
 
         extras_found = set(results.keys()) - undefined_deps
         not_found = undefined_deps - set(results.keys())
