@@ -7,7 +7,7 @@ import unittest
 pom = 'data/sample_installer_iz5/pom.xml'
 path1 = 'data/sample_installer_iz5/izpack/'
 path2 = 'data/sample_installer_iz5/resources/'
-source_path2 = 'data/sample_code_base'
+source_path2 = 'data/sample_code_base/src/'
 
 class TestSeeker(unittest.TestCase):
     """
